==> zeropoint-7.x-4.17.tar.gz: zeropoint/Readme.md <==
*README // ZERO POINT theme for Drupal 7.*

Thank you for downloading this theme!


ABOUT THE 0 POINT THEME:
===========================

**Zero Point** is an advanced responsive, mobile first, HTML5 theme with layout and style configuration options built in that you can control through Drupal's UI. The theme is a highly customized and feature-rich design that goes beyond the basic look and feel of a typical Drupal website. It uses [Yahoo Pure.css](https://purecss.io), a powerful responsive CSS framework and also fully supports right to left languages. Pure is ridiculously tiny. The entire set of modules clocks in at 3.5KB minified and gzipped.

The theme **validates HTML5 and CSS3**, it is cross-browser compatible, and it complies with [WAVE](https://wave.webaim.org/) and [FAE](https://fae.cita.uiuc.edu/).

**8.x-1.x** is a complete redesign made with mobile and SEO in mind: compatible, light and fast.


Theme's features
----------------------------------------

- 1, 2, or 3 column layout with customizable widths using [Yahoo Pure.css Framework](https://purecss.io);
- 15 block regions;
- 11 colour styles + themer setting. Choose themer style from theme's settings and then make appropriate modifications of /_custom/custom-style.css;
- **Helpful body classes** (unique classes for each page, term, website section, etc.);
- Themed blocks, block icons, page icons;
- Drop-down Main menu;
- Primary/secondary links menu position (center, left, right);
- Two font families;
- Different font sizes;
- Round corners for page elements and menus;
- Header image rotator;
- Full breadcrumb;
- Possibility to **change "Submitted by" display** on all nodes;
- **Advanced SEO optimization**;
- Theme's own slideshow;
- Social links integration;
- **Bi-directional right to left (RTL) theming**;
- Works perfect in Multilingual installations.


Advanced theme settings features
----------------------------------------

### Pure.CSS settings

- Responsive CSS files served from Yahoo CDN or locally;
- Layout with fluid width;
- Customizable width for First and Second sidebars;
- Feature to choose the blocks visible on mobile devices.


### Layout settings

- 12 color style options: Grey, Sky, Nature, Ivy, Ink, Orange, Sangue, Lime, Plum, Velvet, Clean and Themer; 
- Two font families (Sans-Serif and Montserrat);
- 3 font size settings;
- Themed blocks;
- 32x32 pixel or 48x48 pixels Block icons for the themed blocks;
- Main Drop-down menu and secondary menu can be positioned (center, left, right);
- No-followed login/register links;
- Three options for Search submit: button, icon or none;
- Page icons - choose a layout with or without page icons;
- Rounded corners for page elements and menus;
- Header image rotator;
- Duplicate the Main Menu at the bottom of the page.


### Other settings

- Breadcrumbs - display or not;
- Change the author and date information on all nodes types;
- Replace "Submitted by" with other text;
- SEO optimization;
- Slideshow;
- Social Media Links at the bottom of the page;
- Remove Drupal META tag & Drupal X-Generator from header;
- Site ID body class - useful in a multi-site environment.


To know more, read [Zero Point handbook](https://drupal.org/node/507792).


Module support
----------------------------------------

This theme can support virtualy any module.

  
Theme customisation
----------------------------------------

If you feel like giving the theme a look of your own, I recommend to play with /_custom/custom-style.css; please read the comments in this file.

To change the rotating images in header you must replace the images in /_custom/headerimg or /_custom/headerimg-rtl with your own, naming them exactly like those in folder. As info, the image dimensions are 846x200 px. 
If you want to change header images rotator behaviour on mobile follow the instructions on the end of /_custom/custom-style.css.


Installation instructions
----------------------------------------

1. Place the zeropoint directory into your themes directory (/themes/zeropoint).
2. Enable the 0 Point theme (/admin/appearance).
3. Go to theme's settings at /admin/appearance/settings/zeropoint and save the configuration. Remember that some of the theme's settings are multilingual variables, so you can have different settings for each language.


UPGRADING to a new version of 0 Point
----------------------------------------

1. Log in as administrator user. 
2. Put the site in "Off-line" mode.
3. Place the zeropoint directory into your themes directory (/themes/zeropoint). In case you have done some theme customization, remember to overwrite theme's custom-style.css with your modified custom-style.css file.
4. Clear cached data at /admin/config/development/performance or "Flush all caches" in Admin Menu and then press CTRL+F5;
5. Put the site in "On-line" mode. It is always a good idea to refresh the browser's cache (CTRL+F5).
6. Check the theme's settings at /admin/appearance/settings/zeropoint. 

NOTE: In some very rare cases, if after upgrading the theme can not be configured 
you should delete all the zeropoint records in the data base.

Resources
----------------------------------------

- [Yahoo Pure.css Framework](https://purecss.io)
- [Github Project Page](https://github.com/yui/pure/)
- [Pure skin builder](https://yui.github.io/skinbuilder/?mode=pure)


Sites using "Zero Point" theme
----------------------------------------

Various implementations of the Zero Point theme can be found here:
- [Dr. Radut](https://www.radut.com/) (customized theme)
- [Smokers Association](https://www.smokersassociation.org/) (customized theme)
- [Shilma, the invisible mask!](https://www.shilma.com/) (customized theme)
- [The European Copyright Office](https://www.eucopyright.com/)
- [Phoenix](https://www.mlnar.ro/)


Related themes
----------------------------------------

- [ABC](https://www.drupal.org/project/abc) - a very customizable HTML5 theme;
- [Black Hole](https://www.drupal.org/project/black_hole) - a dark HTML5 theme.
- [Yahoo Pure.CSS Framework](https://www.drupal.org/project/pure_css) - an advanced responsive, mobile-first, HTML5, base-theme;


Contact
----------------------------------------

My Drupal nick is [Florian](https://www.drupal.org/u/florian) and I can be reached at florian@radut.net (https://www.radut.com).

I can also be contacted for paid customizations of the theme as well as Drupal consulting, installation and customizations.

==> zeropoint-7.x-4.20.tar.gz: zeropoint/Readme.md <==
*ZERO POINT theme for Drupal 7.*

Thank you for downloading this theme!


ABOUT THE 0 POINT THEME:
===========================

**Zero Point** is an advanced responsive, mobile first theme with layout and style configuration options built in that you can control through Drupal's UI. The theme is a highly customized and feature-rich design that goes beyond the basic look and feel of a typical Drupal website. It uses [Yahoo Pure.css](https://purecss.io), a powerful responsive CSS framework and also fully supports right to left languages. Pure is ridiculously tiny. The entire set of modules clocks in at 3.5KB minified and gzipped.

The theme **validates HTML5 and CSS3**, it is cross-browser compatible, and it complies with [WAVE](https://wave.webaim.org/) and [FAE](https://fae.cita.uiuc.edu/).


Theme's features
----------------------------------------

- 1, 2, or 3 column layout with customizable widths using [Yahoo Pure.css Framework](https://purecss.io);
- 15 block regions;
- 8 colour styles + themer setting. Choose themer style from theme's settings and then make appropriate modifications of /_custom/custom-style.css;
- **Helpful body classes** (unique classes for each page, term, website section, etc.);
- Themed blocks, block icons, page icons;
- Drop-down Main menu;
- Primary/secondary links menu position (center, left, right);
- Three font families;
- Different font sizes;
- Round corners for page elements and menus;
- Header image rotator;
- Full breadcrumb;
- Possibility to **change "Submitted by" display** on all nodes;
- **Advanced SEO optimization**;
- Theme's own slideshow with Multilingual support. It now features two distinct variations, each comprising 7 slides: one showcasing full-page images and the other displaying half-page images.
- Social links integration;
- **Bi-directional right to left (RTL) theming**;
- Works perfect in Multilingual installations.


Advanced theme settings features
----------------------------------------

### Pure.CSS settings

- Responsive CSS files served from Yahoo CDN or locally;
- Layout with fluid width;
- Customizable width for First and Second sidebars;
- Feature to choose the blocks visible on mobile devices.


### Layout settings

- 8 color style options: Grey, Sky, Nature, Ivy, Ink, Orange, Sangue, Lime and Themer; 
- Three font families (Sans-Serif, Montserrat and Merriweather);
- Three font size settings;
- Themed blocks;
- 32x32 pixel or 48x48 pixels Block icons for the themed blocks;
- Main Drop-down menu and secondary menu can be positioned (center, left, right);
- No-followed login/register links;
- Three options for Search submit: button, icon or none;
- Page icons - choose a layout with or without page icons;
- Rounded corners for page elements and menus;
- Header image rotator;
- Duplicate the Main Menu at the bottom of the page.


### Other settings

- Breadcrumbs - display or not;
- Change the author and date information on all nodes types;
- Replace "Submitted by" with other text;
- SEO optimization;
- Slideshow;
- Social Media Links at the bottom of the page;
- Remove Drupal META tag & Drupal X-Generator from header;
- Site ID body class - useful in a multi-site environment.


To know more, read [Zero Point handbook](https://drupal.org/node/507792).


Module support
----------------------------------------

The theme can support virtualy any module.
This versatile, **base theme** stands alone, free from dependence on other modules or libraries.

  
Theme customisation
----------------------------------------

If you feel like giving the theme a look of your own, I recommend to play with /_custom/custom-style.css; please read the comments in this file.

#### Header rotator
To change the rotating images in header you must replace the images in /_custom/headerimg or /_custom/headerimg-rtl with your own, naming them exactly like those in folder. As info, the image dimensions are 846x200 px. 
If you want to change header images rotator behaviour on mobile follow the instructions on the end of /_custom/custom-style.css.

#### Slideshow
At www.dr.mt, you'll find a compilation of pre-optimized images for your slideshow. Feel free to download them from this source, where the images are organized into sections.


Installation instructions
----------------------------------------

1. Place the zeropoint directory into your themes directory (/themes/zeropoint).
2. Enable the 0 Point theme (/admin/appearance).
3. Go to theme's settings at /admin/appearance/settings/zeropoint and *save the configuration*. Remember that some of the theme's settings are multilingual variables, so you can have different settings for each language.


UPGRADING to a new version of 0 Point
----------------------------------------

1. Log in as administrator user. 
2. Put the site in "Off-line" mode.
3. Place the zeropoint directory into your themes directory (/themes/zeropoint). In case you have done some theme customization, remember to overwrite theme's custom-style.css with your modified custom-style.css file.
4. Clear cached data at /admin/config/development/performance or "Flush all caches" in Admin Menu and then press CTRL+F5;
5. Put the site in "On-line" mode. It is always a good idea to refresh the browser's cache (CTRL+F5).
6. Check the theme's settings at /admin/appearance/settings/zeropoint. 

NOTE: In some very rare cases, if after upgrading the theme can not be configured you should delete all the zeropoint records in the data base.

Resources
----------------------------------------

- [Yahoo Pure.css Framework](https://purecss.io)
- [Github Project Page](https://github.com/yui/pure/)
- [Pure skin builder](https://yui.github.io/skinbuilder/?mode=pure)


Sites using "Zero Point" theme
----------------------------------------

Various implementations of the Zero Point theme can be found here:
- [Dr. Radut](https://www.radut.com/) (customized theme)
- [Smokers Association](https://www.smokersassociation.org/) (customized theme)
- [Shilma, the invisible mask!](https://www.shilma.com/) (customized theme)
- [The European Copyright Office](https://www.eucopyright.com/)
- [Phoenix](https://www.mlnar.ro/)


Related themes
----------------------------------------

- [ABC](https://www.drupal.org/project/abc) - a very customizable HTML5 theme;
- [Black Hole](https://www.drupal.org/project/black_hole) - a dark HTML5 theme.
- [Yahoo Pure.CSS Framework](https://www.drupal.org/project/pure_css) - an advanced responsive, mobile-first, HTML5, base-theme;


Contact
----------------------------------------

My Drupal nick is [Florian](https://www.drupal.org/u/florian) and I can be reached at florian@radut.net (https://www.radut.com).

I can also be contacted for paid customizations of the theme as well as Drupal consulting, installation and customizations.
